==> igniteui-angular-charts-17.3.0.tgz: package/esm5/lib/RadialLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Array_$type, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var RadialLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeries, _super);
    function RadialLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialLineSeries.$;
        return _this;
    }
    RadialLineSeries.prototype.bc = function () {
        return new RadialLineSeries();
    };
    RadialLineSeries.prototype.get_ey = function () {
        return true;
    };
    RadialLineSeries.prototype.cd = function () {
        return new RadialLineSeriesView(this);
    };
    RadialLineSeries.prototype.o2 = function (a) {
        _super.prototype.o2.call(this, a);
        this.yb = a;
    };
    RadialLineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
    };
    RadialLineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialLineSeries.prototype.wb = function () {
        return true;
    };
    RadialLineSeries.prototype.nk = function (a, b) {
        _super.prototype.nk.call(this, a, b);
        var c = b;
        c.c4();
    };
    RadialLineSeries.prototype.wq = function (a, b) {
        _super.prototype.wq.call(this, a, b);
        var c = b.by;
        var d = b.bx;
        var e = a.f;
        var f = e.count;
        var g = new List$1(Array_$type, 2, f);
        var h = 0;
        for (var i = 0; i < f; i++) {
            var j = new Array(4);
            g.add(j);
            j[0] = this.vn.d(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[1] = this.vn.e(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[2] = this.vn.d(a.f._inner[i][0], a.f._inner[i][2], c, d);
            var k = a.f._inner[i][2];
            j[3] = this.vn.e(a.f._inner[i][0], k, c, d);
            if (k > h) {
                h = k;
            }
        }
        var l = this.getEffectiveViewport1(b);
        this.vt.a2(this, this.wa(), runOn(this, this.vh), this.wd(b), this.we(b));
        var m = false;
        var n = this.vt.b;
        if (n != null) {
            m = true;
        }
        if (m) {
            var o = new ScalerParams(0, b.by, b.bx, this.vk.ch, l);
            this.xs(e, -1, this.w4.count, this.vk, o, b.q);
        }
        var p = b;
        var q = p.dd;
        var r = p.de;
        var s = p.dc;
        this.vt.ad(q, true, false, true, false);
        this.vt.ad(r, true, false, true, false);
        this.vt.ad(s, false, true, false, false);
        s._opacity = 0.75 * this.vt.j;
        p.c5(f, g, false, this.yc, this.wx(g, f - 1, b), p.cv.b, this.hk);
    };
    RadialLineSeries.prototype.pa = function (a, b, c, d) {
        _super.prototype.pa.call(this, a, b, c, d);
        switch (b) {
            case RadialLineSeries.$$p[0]:
                this.pr(false);
                this.om();
                break;
        }
    };
    RadialLineSeries.prototype.get_w7 = function () {
        return true;
    };
    RadialLineSeries.$t = markType(RadialLineSeries, 'RadialLineSeries', AnchoredRadialSeries.$);
    RadialLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:yc:ye', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialLineSeries;
}(AnchoredRadialSeries));
export { RadialLineSeries };
/**
 * @hidden
 */
var RadialLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeriesView, _super);
    function RadialLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c3 = null;
        _this.da = new Path();
        _this.c9 = new Path();
        _this.db = new Path();
        _this.c7 = new Path();
        _this.c6 = new Path();
        _this.c8 = new Path();
        _this.c3 = a;
        return _this;
    }
    RadialLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.uc = Defaults.e;
        }
    };
    Object.defineProperty(RadialLineSeriesView.prototype, "dd", {
        get: function () {
            return this.da;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "de", {
        get: function () {
            return this.db;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "dc", {
        get: function () {
            return this.c9;
        },
        enumerable: false,
        configurable: true
    });
    RadialLineSeriesView.prototype.c4 = function () {
        this.da.an = null;
        this.c9.an = null;
        this.db.an = null;
        this.c7.an = null;
        this.c6.an = null;
        this.c8.an = null;
        this.as();
    };
    RadialLineSeriesView.prototype.c5 = function (a, b, c, d, e, f, g) {
        this.cz.wz.m(this.da, this.c9, this.db, a, b, c, d, e, f, g);
        this.as();
    };
    RadialLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    RadialLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.c6.an = this.c9.an;
        this.c7.an = this.da.an;
        this.c8.an = this.db.an;
        this.c7._stroke = a;
        this.c7.ad = this.e.hl + 3;
        this.c8._stroke = a;
        this.c8.ad = this.e.hl + 3;
        this.c6._fill = a;
        this.c6._opacity = 1;
    };
    RadialLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.c6);
                a.t(this.c7);
                a.t(this.c8);
            }
            else {
                a.t(this.c9);
                a.t(this.da);
                a.t(this.db);
            }
        }
    };
    RadialLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.a5.exportPathData(a, this.da, "lowerShape", ["Lower", "Main"]);
        this.e.a5.exportPathData(a, this.db, "upperShape", ["Upper"]);
        this.e.a5.exportPathData(a, this.c9, "translucentShape", ["Translucent"]);
    };
    RadialLineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.s8 = a;
        this.e.is = 3;
        this.e.it = 1;
        this.e.iu = 4;
        this.e.gk = false;
    };
    RadialLineSeriesView.$t = markType(RadialLineSeriesView, 'RadialLineSeriesView', AnchoredRadialSeriesView.$);
    return RadialLineSeriesView;
}(AnchoredRadialSeriesView));
export { RadialLineSeriesView };

==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/RadialLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { Array_$type, runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-angular-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var RadialLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeries, _super);
    function RadialLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialLineSeries.$;
        return _this;
    }
    RadialLineSeries.prototype.bb = function () {
        return new RadialLineSeries();
    };
    RadialLineSeries.prototype.get_e5 = function () {
        return true;
    };
    RadialLineSeries.prototype.ci = function () {
        return new RadialLineSeriesView(this);
    };
    RadialLineSeries.prototype.px = function (a) {
        _super.prototype.px.call(this, a);
        this.zp = a;
    };
    RadialLineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
    };
    RadialLineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    RadialLineSeries.prototype.xp = function () {
        return true;
    };
    RadialLineSeries.prototype.n7 = function (a, b) {
        _super.prototype.n7.call(this, a, b);
        var c = b;
        c.c4();
    };
    RadialLineSeries.prototype.x4 = function (a, b) {
        _super.prototype.x4.call(this, a, b);
        var c = b.by;
        var d = b.bx;
        var e = a.f;
        var f = e.count;
        var g = new List$1(Array_$type, 2, f);
        var h = 0;
        for (var i = 0; i < f; i++) {
            var j = new Array(4);
            g.add(j);
            j[0] = this.w1.d(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[1] = this.w1.e(a.f._inner[i][0], a.f._inner[i][1], c, d);
            j[2] = this.w1.d(a.f._inner[i][0], a.f._inner[i][2], c, d);
            var k = a.f._inner[i][2];
            j[3] = this.w1.e(a.f._inner[i][0], k, c, d);
            if (k > h) {
                h = k;
            }
        }
        var l = this.getEffectiveViewport1(b);
        this.w7.a2(this, this.xo(), runOn(this, this.wv), this.xr(b), this.xs(b));
        var m = false;
        var n = this.w7.b;
        if (n != null) {
            m = true;
        }
        if (m) {
            var o = new ScalerParams(0, b.by, b.bx, this.wy.ch, l);
            this.y6(e, -1, this.yi.count, this.wy, o, b.q);
        }
        var p = b;
        var q = p.dd;
        var r = p.de;
        var s = p.dc;
        this.w7.ad(q, true, false, true, false);
        this.w7.ad(r, true, false, true, false);
        this.w7.ad(s, false, true, false, false);
        s._opacity = 0.75 * this.w7.j;
        p.c5(f, g, false, this.zq, this.yb(g, f - 1, b), p.cv.b, this.hu);
    };
    RadialLineSeries.prototype.p5 = function (a, b, c, d) {
        _super.prototype.p5.call(this, a, b, c, d);
        switch (b) {
            case RadialLineSeries.$$p[0]:
                this.qm(false);
                this.ph();
                break;
        }
    };
    RadialLineSeries.prototype.get_yl = function () {
        return true;
    };
    RadialLineSeries.$t = markType(RadialLineSeries, 'RadialLineSeries', AnchoredRadialSeries.$);
    RadialLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:zq:zs', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return RadialLineSeries;
}(AnchoredRadialSeries));
export { RadialLineSeries };
/**
 * @hidden
 */
var RadialLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialLineSeriesView, _super);
    function RadialLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c3 = null;
        _this.da = new Path();
        _this.c9 = new Path();
        _this.db = new Path();
        _this.c7 = new Path();
        _this.c6 = new Path();
        _this.c8 = new Path();
        _this.c3 = a;
        return _this;
    }
    RadialLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.vp = Defaults.e;
        }
    };
    Object.defineProperty(RadialLineSeriesView.prototype, "dd", {
        get: function () {
            return this.da;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "de", {
        get: function () {
            return this.db;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RadialLineSeriesView.prototype, "dc", {
        get: function () {
            return this.c9;
        },
        enumerable: false,
        configurable: true
    });
    RadialLineSeriesView.prototype.c4 = function () {
        this.da.an = null;
        this.c9.an = null;
        this.db.an = null;
        this.c7.an = null;
        this.c6.an = null;
        this.c8.an = null;
        this.as();
    };
    RadialLineSeriesView.prototype.c5 = function (a, b, c, d, e, f, g) {
        this.cz.yd.m(this.da, this.c9, this.db, a, b, c, d, e, f, g);
        this.as();
    };
    RadialLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    RadialLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.c6.an = this.c9.an;
        this.c7.an = this.da.an;
        this.c8.an = this.db.an;
        this.c7._stroke = a;
        this.c7.ad = this.e.hv + 3;
        this.c8._stroke = a;
        this.c8.ad = this.e.hv + 3;
        this.c6._fill = a;
        this.c6._opacity = 1;
    };
    RadialLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.c6);
                a.t(this.c7);
                a.t(this.c8);
            }
            else {
                a.t(this.c9);
                a.t(this.da);
                a.t(this.db);
            }
        }
    };
    RadialLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.a4.exportPathData(a, this.da, "lowerShape", ["Lower", "Main"]);
        this.e.a4.exportPathData(a, this.db, "upperShape", ["Upper"]);
        this.e.a4.exportPathData(a, this.c9, "translucentShape", ["Translucent"]);
    };
    RadialLineSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.uj = a;
        this.e.i2 = 3;
        this.e.i3 = 1;
        this.e.i4 = 4;
        this.e.gu = false;
    };
    RadialLineSeriesView.$t = markType(RadialLineSeriesView, 'RadialLineSeriesView', AnchoredRadialSeriesView.$);
    return RadialLineSeriesView;
}(AnchoredRadialSeriesView));
export { RadialLineSeriesView };
